@@ -3,8 +3,9 @@ Main interface for machinelearning service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.machinelearning import (
+    from mypy_boto3_machinelearning import (
         BatchPredictionAvailableWaiter,
         Client,
         DataSourceAvailableWaiter,
@@ -15,7 +16,7 @@ Usage::
         EvaluationAvailableWaiter,
         MLModelAvailableWaiter,
         MachineLearningClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -31,6 +32,7 @@ Usage::
     describe_data_sources_paginator: DescribeDataSourcesPaginator = client.get_paginator("describe_data_sources")
     describe_evaluations_paginator: DescribeEvaluationsPaginator = client.get_paginator("describe_evaluations")
     describe_ml_models_paginator: DescribeMLModelsPaginator = client.get_paginator("describe_ml_models")
+    ```
 """
 from mypy_boto3_machinelearning.client import MachineLearningClient as Client, MachineLearningClient
 from mypy_boto3_machinelearning.paginator import (
