@@ -3,13 +3,15 @@ Main interface for machinelearning service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.machinelearning import MachineLearningClient
+    from mypy_boto3_machinelearning import MachineLearningClient
 
     session = boto3.Session()
 
     client: MachineLearningClient = boto3.client("machinelearning")
     session_client: MachineLearningClient = session.client("machinelearning")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
