@@ -3,8 +3,11 @@ Main interface for machinelearning service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.machinelearning import (
+
+    from mypy_boto3_machinelearning import MachineLearningClient
+    from mypy_boto3_machinelearning import (
         DescribeBatchPredictionsPaginator,
         DescribeDataSourcesPaginator,
         DescribeEvaluationsPaginator,
@@ -17,6 +20,7 @@ Usage::
     describe_data_sources_paginator: DescribeDataSourcesPaginator = client.get_paginator("describe_data_sources")
     describe_evaluations_paginator: DescribeEvaluationsPaginator = client.get_paginator("describe_evaluations")
     describe_ml_models_paginator: DescribeMLModelsPaginator = client.get_paginator("describe_ml_models")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
