@@ -3,9 +3,11 @@ Main interface for machinelearning service type definitions.
 
 Usage::
 
-    from mypy_boto3.machinelearning.type_defs import BatchPredictionTypeDef
+    ```python
+    from mypy_boto3_machinelearning.type_defs import BatchPredictionTypeDef
 
     data: BatchPredictionTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
