@@ -3,8 +3,11 @@ Main interface for machinelearning service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.machinelearning import (
+
+    from mypy_boto3_machinelearning import MachineLearningClient
+    from mypy_boto3_machinelearning import (
         BatchPredictionAvailableWaiter,
         DataSourceAvailableWaiter,
         EvaluationAvailableWaiter,
@@ -17,6 +20,7 @@ Usage::
     data_source_available_waiter: DataSourceAvailableWaiter = client.get_waiter("data_source_available")
     evaluation_available_waiter: EvaluationAvailableWaiter = client.get_waiter("evaluation_available")
     ml_model_available_waiter: MLModelAvailableWaiter = client.get_waiter("ml_model_available")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
